@@ -20,25 +20,23 @@
 #include "kcardthemewidget_p.h"
 
 #include "common.h"
-
-#include <KConfigDialog>
-#include <KDebug>
-#include <KLineEdit>
-#include <KLocale>
-#include <KGlobal>
 #include <KImageCache>
-#include <KPushButton>
-#include <KStandardDirs>
-#include <knewstuff3/downloaddialog.h>
+#include <KConfigDialog>
+#include <QDebug>
+#include <KLineEdit>
+#include <KLocalizedString>
+#include <KImageCache>
+#include <QPushButton>
+#include <kns3/downloaddialog.h>
 
 #include <QtCore/QMutexLocker>
 #include <QtCore/QScopedPointer>
-#include <QtGui/QApplication>
-#include <QtGui/QFontMetrics>
-#include <QtGui/QListView>
-#include <QtGui/QPainter>
-#include <QtGui/QPixmap>
-#include <QtGui/QVBoxLayout>
+#include <QApplication>
+#include <QFontMetrics>
+#include <QListView>
+#include <QPainter>
+#include <QPixmap>
+#include <QVBoxLayout>
 #include <QtSvg/QSvgRenderer>
 
 
@@ -183,8 +181,7 @@ void CardThemeModel::reload()
         qSort( previewsNeeded.begin(), previewsNeeded.end(), lessThanByDisplayName ) ;
 
         m_thread = new PreviewThread( d, previewsNeeded );
-        connect( m_thread, SIGNAL(previewRendered(KCardTheme,QImage)),
-                 this, SLOT(submitPreview(KCardTheme,QImage)), Qt::QueuedConnection );
+        connect(m_thread, &PreviewThread::previewRendered, this, &CardThemeModel::submitPreview, Qt::QueuedConnection );
         m_thread->start();
     }
 }
@@ -396,7 +393,7 @@ KCardThemeWidget::KCardThemeWidget( const QSet<QString> & requiredFeatures, cons
     connect( d->listView->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)), d, SLOT(updateLineEdit(QModelIndex)) );
     connect( d->hiddenLineEdit, SIGNAL(textChanged(QString)), d, SLOT(updateListView(QString)) );
 
-    d->newDeckButton = new KPushButton( KIcon( QLatin1String( "get-hot-new-stuff") ), i18n("Get New Card Decks..." ), this );
+    d->newDeckButton = new QPushButton( QIcon::fromTheme( QLatin1String( "get-hot-new-stuff") ), i18n("Get New Card Decks..." ), this );
     connect( d->newDeckButton, SIGNAL(clicked(bool)), d, SLOT(getNewCardThemes()) );
 
     QHBoxLayout * hLayout = new QHBoxLayout();
@@ -440,8 +437,7 @@ KCardThemeDialog::KCardThemeDialog( QWidget * parent, KConfigSkeleton * config,
     addPage( new KCardThemeWidget( requiredFeatures, previewString, this ), QString() );
 
     setFaceType( KPageDialog::Plain );
-    setButtons( KDialog::Ok | KDialog::Apply | KDialog::Cancel );
-    showButtonSeparator( false );
+    setStandardButtons( QDialogButtonBox::Ok | QDialogButtonBox::Apply | QDialogButtonBox::Cancel);
 }
 
 
